aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorPapoteur <papoteur@mageialinux-online.org>2015-11-20 09:08:50 +0100
committerPapoteur <papoteur@mageialinux-online.org>2015-11-20 09:08:50 +0100
commitf7c6c4e5af001133e3eb0cc49c512ab636fb4a3d (patch)
tree75b0a2b9f56b709335248546429852b5a4297054
parent2f8312d66a3dde7871e2f7337c561a9d917ff776 (diff)
downloadMageiaSync-f7c6c4e5af001133e3eb0cc49c512ab636fb4a3d.tar
MageiaSync-f7c6c4e5af001133e3eb0cc49c512ab636fb4a3d.tar.gz
MageiaSync-f7c6c4e5af001133e3eb0cc49c512ab636fb4a3d.tar.bz2
MageiaSync-f7c6c4e5af001133e3eb0cc49c512ab636fb4a3d.tar.xz
MageiaSync-f7c6c4e5af001133e3eb0cc49c512ab636fb4a3d.zip
Reverse "not creating new line when checking" which was bugous
-rw-r--r--mageiaSync/mageiasync.py7
1 files changed, 5 insertions, 2 deletions
diff --git a/mageiaSync/mageiasync.py b/mageiaSync/mageiasync.py
index 792446d..84d5e85 100644
--- a/mageiaSync/mageiasync.py
+++ b/mageiaSync/mageiasync.py
@@ -505,8 +505,11 @@ class IsosViewer(QMainWindow, mageiaSyncUI.Ui_mainWindow):
# Look for ISO in local list
item=self.model.findItems(name,QtCore.Qt.MatchExactly,1)[0]
except:
- # Remote ISO is not yet in local directory. We pass.
- break
+ # Remote ISO is not yet in local directory. We add it in localList and create the directory
+ self.localAdd(path,name,0)
+ basedir=QtCore.QDir(self.destination)
+ basedir.mkdir(path)
+ item=self.model.findItems(name,QtCore.Qt.MatchExactly,1)[0]
row=self.model.indexFromItem(item).row()
if self.location == "" :
self.nameWithPath='rsync://'+self.user+'@bcd.mageia.org/isos/'+self.release+'/'+path